@@ -233,13 +233,20 @@ nlxb <- function(formula, start, trace = FALSE, data = NULL,
             feval <- feval + 1  # count as a function evaluation to force stop
         } else {
             # solution OK
+            if (trace) {
+              cat("delta:")
+              print(delta)
+              cat("gjty:")
+              print(gjty)
+            }
             gproj <- crossprod(delta, gjty)
             gangle <- gproj/sqrt(crossprod(gjty) * crossprod(delta))
             gangle <- 180 * acos(sign(gangle)*min(1, abs(gangle)))/pi
             if (trace) 
                 cat("gradient projection = ", gproj, " g-delta-angle=", 
                   gangle, "\n")
-            if (is.na(gproj) || (gproj >= 0)) {
+            if (is.na(gproj)) stop("gproj is NA")
+            if (is.na(gproj) || (gproj > 0)) {
                 # uphill direction -- should NOT be possible
                 if (lamda < 1000 * .Machine$double.eps) 
                   lamda <- 1000 * .Machine$double.eps
